/* 
 * 
 * This file is GENERATED by the varargs library. Modify the
 * code at your peril :).
 * 
 * This interpreter parses the arguments for a vararg C function,
 * putting them in the correct locations, and then calls the function.
 * 
 * Mike Rainey (mrainey@cs.uchicago.edu)
 */
	.text
VarargInterp:
	/* live= GP={%edi %esi %ebx} spilled=  */
	pushl	%ebp
	movl	%esp, %ebp
	movl	12(%ebp), %ecx
	subl	$4088, %esp
	jmp	interpEntry96
interp97:
	addl	$28, %ecx
interpEntry96:
	cmpl	16(%ebp), %ecx
	jge	gotoC98
entry1:
	cmpl	$0, (%ecx)
	je	kind.GPR2
	cmpl	$1, (%ecx)
	je	kind.FPR3
	cmpl	$2, (%ecx)
	je	kind.STK4
	cmpl	$3, (%ecx)
	je	kind.FSTK5
	jmp	vararg_error
kind.GPR2:
	cmpl	$8, 4(%ecx)
	je	width.GPR.86
	cmpl	$16, 4(%ecx)
	je	width.GPR.167
	cmpl	$32, 4(%ecx)
	je	width.GPR.328
	cmpl	$64, 4(%ecx)
	je	width.GPR.649
	jmp	vararg_error
kind.FPR3:
	cmpl	$8, 4(%ecx)
	je	width.FPR.8A
	cmpl	$16, 4(%ecx)
	je	width.FPR.16B
	cmpl	$32, 4(%ecx)
	je	width.FPR.32C
	cmpl	$64, 4(%ecx)
	je	width.FPR.64D
	jmp	vararg_error
kind.STK4:
	cmpl	$8, 4(%ecx)
	je	width.STK.8E
	cmpl	$16, 4(%ecx)
	je	width.STK.16F
	cmpl	$32, 4(%ecx)
	je	width.STK.3210
	cmpl	$64, 4(%ecx)
	je	width.STK.6411
	jmp	vararg_error
kind.FSTK5:
	cmpl	$8, 4(%ecx)
	je	width.FSTK.812
	cmpl	$16, 4(%ecx)
	je	width.FSTK.1613
	cmpl	$32, 4(%ecx)
	je	width.FSTK.3214
	cmpl	$64, 4(%ecx)
	je	width.FSTK.6415
	jmp	vararg_error
width.GPR.86:
	cmpl	$8, 8(%ecx)
	je	narrowing.GPR.8.816
	cmpl	$16, 8(%ecx)
	je	narrowing.GPR.8.1617
	cmpl	$32, 8(%ecx)
	je	narrowing.GPR.8.3218
	cmpl	$64, 8(%ecx)
	je	narrowing.GPR.8.6419
	jmp	vararg_error
width.GPR.167:
	cmpl	$8, 8(%ecx)
	je	narrowing.GPR.16.81A
	cmpl	$16, 8(%ecx)
	je	narrowing.GPR.16.161B
	cmpl	$32, 8(%ecx)
	je	narrowing.GPR.16.321C
	cmpl	$64, 8(%ecx)
	je	narrowing.GPR.16.641D
	jmp	vararg_error
width.GPR.328:
	cmpl	$8, 8(%ecx)
	je	narrowing.GPR.32.81E
	cmpl	$16, 8(%ecx)
	je	narrowing.GPR.32.161F
	cmpl	$32, 8(%ecx)
	je	narrowing.GPR.32.3220
	cmpl	$64, 8(%ecx)
	je	narrowing.GPR.32.6421
	jmp	vararg_error
width.GPR.649:
	cmpl	$8, 8(%ecx)
	je	narrowing.GPR.64.822
	cmpl	$16, 8(%ecx)
	je	narrowing.GPR.64.1623
	cmpl	$32, 8(%ecx)
	je	narrowing.GPR.64.3224
	cmpl	$64, 8(%ecx)
	je	narrowing.GPR.64.6425
	jmp	vararg_error
width.FPR.8A:
	cmpl	$8, 8(%ecx)
	je	narrowing.FPR.8.826
	cmpl	$16, 8(%ecx)
	je	narrowing.FPR.8.1627
	cmpl	$32, 8(%ecx)
	je	narrowing.FPR.8.3228
	cmpl	$64, 8(%ecx)
	je	narrowing.FPR.8.6429
	jmp	vararg_error
width.FPR.16B:
	cmpl	$8, 8(%ecx)
	je	narrowing.FPR.16.82A
	cmpl	$16, 8(%ecx)
	je	narrowing.FPR.16.162B
	cmpl	$32, 8(%ecx)
	je	narrowing.FPR.16.322C
	cmpl	$64, 8(%ecx)
	je	narrowing.FPR.16.642D
	jmp	vararg_error
width.FPR.32C:
	cmpl	$8, 8(%ecx)
	je	narrowing.FPR.32.82E
	cmpl	$16, 8(%ecx)
	je	narrowing.FPR.32.162F
	cmpl	$32, 8(%ecx)
	je	narrowing.FPR.32.3230
	cmpl	$64, 8(%ecx)
	je	narrowing.FPR.32.6431
	jmp	vararg_error
width.FPR.64D:
	cmpl	$8, 8(%ecx)
	je	narrowing.FPR.64.832
	cmpl	$16, 8(%ecx)
	je	narrowing.FPR.64.1633
	cmpl	$32, 8(%ecx)
	je	narrowing.FPR.64.3234
	cmpl	$64, 8(%ecx)
	je	narrowing.FPR.64.6435
	jmp	vararg_error
width.STK.8E:
	cmpl	$8, 8(%ecx)
	je	narrowing.STK.8.836
	cmpl	$16, 8(%ecx)
	je	narrowing.STK.8.1637
	cmpl	$32, 8(%ecx)
	je	narrowing.STK.8.3238
	cmpl	$64, 8(%ecx)
	je	narrowing.STK.8.6439
	jmp	vararg_error
width.STK.16F:
	cmpl	$8, 8(%ecx)
	je	narrowing.STK.16.83A
	cmpl	$16, 8(%ecx)
	je	narrowing.STK.16.163B
	cmpl	$32, 8(%ecx)
	je	narrowing.STK.16.323C
	cmpl	$64, 8(%ecx)
	je	narrowing.STK.16.643D
	jmp	vararg_error
width.STK.3210:
	cmpl	$8, 8(%ecx)
	je	narrowing.STK.32.83E
	cmpl	$16, 8(%ecx)
	je	narrowing.STK.32.163F
	cmpl	$32, 8(%ecx)
	je	narrowing.STK.32.3240
	cmpl	$64, 8(%ecx)
	je	narrowing.STK.32.6441
	jmp	vararg_error
width.STK.6411:
	cmpl	$8, 8(%ecx)
	je	narrowing.STK.64.842
	cmpl	$16, 8(%ecx)
	je	narrowing.STK.64.1643
	cmpl	$32, 8(%ecx)
	je	narrowing.STK.64.3244
	cmpl	$64, 8(%ecx)
	je	narrowing.STK.64.6445
	jmp	vararg_error
width.FSTK.812:
	cmpl	$8, 8(%ecx)
	je	narrowing.FSTK.8.846
	cmpl	$16, 8(%ecx)
	je	narrowing.FSTK.8.1647
	cmpl	$32, 8(%ecx)
	je	narrowing.FSTK.8.3248
	cmpl	$64, 8(%ecx)
	je	narrowing.FSTK.8.6449
	jmp	vararg_error
width.FSTK.1613:
	cmpl	$8, 8(%ecx)
	je	narrowing.FSTK.16.84A
	cmpl	$16, 8(%ecx)
	je	narrowing.FSTK.16.164B
	cmpl	$32, 8(%ecx)
	je	narrowing.FSTK.16.324C
	cmpl	$64, 8(%ecx)
	je	narrowing.FSTK.16.644D
	jmp	vararg_error
width.FSTK.3214:
	cmpl	$8, 8(%ecx)
	je	narrowing.FSTK.32.84E
	cmpl	$16, 8(%ecx)
	je	narrowing.FSTK.32.164F
	cmpl	$32, 8(%ecx)
	je	narrowing.FSTK.32.3250
	cmpl	$64, 8(%ecx)
	je	narrowing.FSTK.32.6451
	jmp	vararg_error
width.FSTK.6415:
	cmpl	$8, 8(%ecx)
	je	narrowing.FSTK.64.852
	cmpl	$16, 8(%ecx)
	je	narrowing.FSTK.64.1653
	cmpl	$32, 8(%ecx)
	je	narrowing.FSTK.64.3254
	cmpl	$64, 8(%ecx)
	je	narrowing.FSTK.64.6455
	jmp	vararg_error
narrowing.GPR.8.816:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.8.8.stk56
	jmp	vararg_error
narrowing.GPR.8.1617:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.8.16.stk57
	jmp	vararg_error
narrowing.GPR.8.3218:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.8.32.stk58
	jmp	vararg_error
narrowing.GPR.8.6419:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.8.64.stk59
	jmp	vararg_error
narrowing.GPR.16.81A:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.16.8.stk5A
	jmp	vararg_error
narrowing.GPR.16.161B:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.16.16.stk5B
	jmp	vararg_error
narrowing.GPR.16.321C:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.16.32.stk5C
	jmp	vararg_error
narrowing.GPR.16.641D:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.16.64.stk5D
	jmp	vararg_error
narrowing.GPR.32.81E:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.32.8.stk5E
	jmp	vararg_error
narrowing.GPR.32.161F:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.32.16.stk5F
	jmp	vararg_error
narrowing.GPR.32.3220:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.32.32.stk60
	jmp	vararg_error
narrowing.GPR.32.6421:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.32.64.stk61
	jmp	vararg_error
narrowing.GPR.64.822:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.64.8.stk62
	jmp	vararg_error
narrowing.GPR.64.1623:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.64.16.stk63
	jmp	vararg_error
narrowing.GPR.64.3224:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.64.32.stk64
	jmp	vararg_error
narrowing.GPR.64.6425:
	cmpl	$0, 12(%ecx)
	je	loc.GPR.64.64.stk65
	jmp	vararg_error
narrowing.FPR.8.826:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.8.8.stk66
	jmp	vararg_error
narrowing.FPR.8.1627:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.8.16.stk67
	jmp	vararg_error
narrowing.FPR.8.3228:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.8.32.stk68
	jmp	vararg_error
narrowing.FPR.8.6429:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.8.64.stk69
	jmp	vararg_error
narrowing.FPR.16.82A:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.16.8.stk6A
	jmp	vararg_error
narrowing.FPR.16.162B:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.16.16.stk6B
	jmp	vararg_error
narrowing.FPR.16.322C:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.16.32.stk6C
	jmp	vararg_error
narrowing.FPR.16.642D:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.16.64.stk6D
	jmp	vararg_error
narrowing.FPR.32.82E:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.32.8.stk6E
	jmp	vararg_error
narrowing.FPR.32.162F:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.32.16.stk6F
	jmp	vararg_error
narrowing.FPR.32.3230:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.32.32.stk70
	jmp	vararg_error
narrowing.FPR.32.6431:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.32.64.stk71
	jmp	vararg_error
narrowing.FPR.64.832:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.64.8.stk72
	jmp	vararg_error
narrowing.FPR.64.1633:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.64.16.stk73
	jmp	vararg_error
narrowing.FPR.64.3234:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.64.32.stk74
	jmp	vararg_error
narrowing.FPR.64.6435:
	cmpl	$0, 12(%ecx)
	je	loc.FPR.64.64.stk75
	jmp	vararg_error
narrowing.STK.8.836:
	jmp	loc.STK.8.8.stk76
	jmp	vararg_error
narrowing.STK.8.1637:
	jmp	loc.STK.8.16.stk77
	jmp	vararg_error
narrowing.STK.8.3238:
	jmp	loc.STK.8.32.stk78
	jmp	vararg_error
narrowing.STK.8.6439:
	jmp	loc.STK.8.64.stk79
	jmp	vararg_error
narrowing.STK.16.83A:
	jmp	loc.STK.16.8.stk7A
	jmp	vararg_error
narrowing.STK.16.163B:
	jmp	loc.STK.16.16.stk7B
	jmp	vararg_error
narrowing.STK.16.323C:
	jmp	loc.STK.16.32.stk7C
	jmp	vararg_error
narrowing.STK.16.643D:
	jmp	loc.STK.16.64.stk7D
	jmp	vararg_error
narrowing.STK.32.83E:
	jmp	loc.STK.32.8.stk7E
	jmp	vararg_error
narrowing.STK.32.163F:
	jmp	loc.STK.32.16.stk7F
	jmp	vararg_error
narrowing.STK.32.3240:
	jmp	loc.STK.32.32.stk80
	jmp	vararg_error
narrowing.STK.32.6441:
	jmp	loc.STK.32.64.stk81
	jmp	vararg_error
narrowing.STK.64.842:
	jmp	loc.STK.64.8.stk82
	jmp	vararg_error
narrowing.STK.64.1643:
	jmp	loc.STK.64.16.stk83
	jmp	vararg_error
narrowing.STK.64.3244:
	jmp	loc.STK.64.32.stk84
	jmp	vararg_error
narrowing.STK.64.6445:
	jmp	loc.STK.64.64.stk85
	jmp	vararg_error
narrowing.FSTK.8.846:
	jmp	loc.FSTK.8.8.stk86
	jmp	vararg_error
narrowing.FSTK.8.1647:
	jmp	loc.FSTK.8.16.stk87
	jmp	vararg_error
narrowing.FSTK.8.3248:
	jmp	loc.FSTK.8.32.stk88
	jmp	vararg_error
narrowing.FSTK.8.6449:
	jmp	loc.FSTK.8.64.stk89
	jmp	vararg_error
narrowing.FSTK.16.84A:
	jmp	loc.FSTK.16.8.stk8A
	jmp	vararg_error
narrowing.FSTK.16.164B:
	jmp	loc.FSTK.16.16.stk8B
	jmp	vararg_error
narrowing.FSTK.16.324C:
	jmp	loc.FSTK.16.32.stk8C
	jmp	vararg_error
narrowing.FSTK.16.644D:
	jmp	loc.FSTK.16.64.stk8D
	jmp	vararg_error
narrowing.FSTK.32.84E:
	jmp	loc.FSTK.32.8.stk8E
	jmp	vararg_error
narrowing.FSTK.32.164F:
	jmp	loc.FSTK.32.16.stk8F
	jmp	vararg_error
narrowing.FSTK.32.3250:
	jmp	loc.FSTK.32.32.stk90
	jmp	vararg_error
narrowing.FSTK.32.6451:
	jmp	loc.FSTK.32.64.stk91
	jmp	vararg_error
narrowing.FSTK.64.852:
	jmp	loc.FSTK.64.8.stk92
	jmp	vararg_error
narrowing.FSTK.64.1653:
	jmp	loc.FSTK.64.16.stk93
	jmp	vararg_error
narrowing.FSTK.64.3254:
	jmp	loc.FSTK.64.32.stk94
	jmp	vararg_error
narrowing.FSTK.64.6455:
	jmp	loc.FSTK.64.64.stk95
	jmp	vararg_error
loc.GPR.8.8.stk56:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.8.16.stk57:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.8.32.stk58:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.8.64.stk59:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.16.8.stk5A:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.16.16.stk5B:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.16.32.stk5C:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.16.64.stk5D:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.32.8.stk5E:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.32.16.stk5F:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.32.32.stk60:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.32.64.stk61:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.64.8.stk62:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.64.16.stk63:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.64.32.stk64:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.GPR.64.64.stk65:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.8.8.stk66:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.8.16.stk67:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.8.32.stk68:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.8.64.stk69:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.16.8.stk6A:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.16.16.stk6B:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.16.32.stk6C:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.16.64.stk6D:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.32.8.stk6E:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.32.16.stk6F:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.32.32.stk70:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.32.64.stk71:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.64.8.stk72:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.64.16.stk73:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.64.32.stk74:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FPR.64.64.stk75:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.STK.8.8.stk76:
	movzbl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movb	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.8.16.stk77:
	movzbl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movb	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.8.32.stk78:
	movzbl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movb	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.8.64.stk79:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.STK.16.8.stk7A:
	movzwl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movw	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.16.16.stk7B:
	movzwl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movw	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.16.32.stk7C:
	movzwl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movw	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.16.64.stk7D:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.STK.32.8.stk7E:
	movl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movl	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.32.16.stk7F:
	movl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movl	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.32.32.stk80:
	movl	20(%ecx), %eax
	movl	12(%ecx), %edx
	movl	%eax, (%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.STK.32.64.stk81:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.STK.64.8.stk82:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.STK.64.16.stk83:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.STK.64.32.stk84:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.STK.64.64.stk85:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.8.8.stk86:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.8.16.stk87:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.8.32.stk88:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.8.64.stk89:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.16.8.stk8A:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.16.16.stk8B:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.16.32.stk8C:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.16.64.stk8D:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.32.8.stk8E:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.32.16.stk8F:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.32.32.stk90:
	movl	12(%ecx), %eax
	flds	20(%ecx)
	fstps	(%esp,%eax,1)
	jmp	interp97
	jmp	vararg_error
loc.FSTK.32.64.stk91:
	movl	12(%ecx), %edx
	flds	20(%ecx)
	fstps	(%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
loc.FSTK.64.8.stk92:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.64.16.stk93:
	jmp	vararg_error
	jmp	interp97
	jmp	vararg_error
loc.FSTK.64.32.stk94:
	movl	12(%ecx), %eax
	fldl	20(%ecx)
	fstpl	(%esp,%eax,1)
	jmp	interp97
	jmp	vararg_error
loc.FSTK.64.64.stk95:
	movl	12(%ecx), %edx
	fldl	20(%ecx)
	fstpl	(%esp,%edx,1)
	jmp	interp97
	jmp	vararg_error
gotoC98:
	/* Liveout:  GP={%eax}  */
	call	*8(%ebp)
	leave
	/* live= GP={%edi %esi %ebx} spilled=  */
	ret
	.global	VarargInterp
