/* 
 * 
 * This file is GENERATED by the varargs library. Modify the
 * code at your peril :).
 * 
 * This interpreter parses the arguments for a vararg C function,
 * putting them in the correct locations, and then calls the function.
 * 
 * Mike Rainey (mrainey@cs.uchicago.edu)
 */
	.text
VarargInterp:
	b,a	interpEntryL1E2
interpL1E3:
	add	%o1, 28, %o1
interpEntryL1E2:
	cmp	%o1, %o2
	bge,a	gotoCL1E4
	nop
entryL1:
	ld	[%o1+0], %o3
	cmp	%o3, %g0
	be,a	kind.GPRL2
	nop
	ld	[%o1+0], %o4
	cmp	%o4, 1
	be,a	kind.FPRL3
	nop
	ld	[%o1+0], %o3
	cmp	%o3, 2
	be,a	kind.STKL4
	nop
	ld	[%o1+0], %o4
	cmp	%o4, 3
	be,a	kind.FSTKL5
	nop
	b,a	vararg_error
kind.GPRL2:
	ld	[%o1+4], %o3
	cmp	%o3, 8
	be,a	width.GPR.8L6
	nop
	ld	[%o1+4], %o4
	cmp	%o4, 16
	be,a	width.GPR.16L7
	nop
	ld	[%o1+4], %o3
	cmp	%o3, 32
	be,a	width.GPR.32L8
	nop
	ld	[%o1+4], %o4
	cmp	%o4, 64
	be,a	width.GPR.64L9
	nop
	b,a	vararg_error
kind.FPRL3:
	ld	[%o1+4], %o3
	cmp	%o3, 8
	be,a	width.FPR.8LA
	nop
	ld	[%o1+4], %o4
	cmp	%o4, 16
	be,a	width.FPR.16LB
	nop
	ld	[%o1+4], %o3
	cmp	%o3, 32
	be,a	width.FPR.32LC
	nop
	ld	[%o1+4], %o4
	cmp	%o4, 64
	be,a	width.FPR.64LD
	nop
	b,a	vararg_error
kind.STKL4:
	ld	[%o1+4], %o3
	cmp	%o3, 8
	be,a	width.STK.8LE
	nop
	ld	[%o1+4], %o4
	cmp	%o4, 16
	be,a	width.STK.16LF
	nop
	ld	[%o1+4], %o3
	cmp	%o3, 32
	be,a	width.STK.32L10
	nop
	ld	[%o1+4], %o4
	cmp	%o4, 64
	be,a	width.STK.64L11
	nop
	b,a	vararg_error
kind.FSTKL5:
	ld	[%o1+4], %o3
	cmp	%o3, 8
	be,a	width.FSTK.8L12
	nop
	ld	[%o1+4], %o4
	cmp	%o4, 16
	be,a	width.FSTK.16L13
	nop
	ld	[%o1+4], %o3
	cmp	%o3, 32
	be,a	width.FSTK.32L14
	nop
	ld	[%o1+4], %o4
	cmp	%o4, 64
	be,a	width.FSTK.64L15
	nop
	b,a	vararg_error
width.GPR.8L6:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.GPR.8.8L16
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.GPR.8.16L17
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.GPR.8.32L18
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.GPR.8.64L19
	nop
	b,a	vararg_error
width.GPR.16L7:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.GPR.16.8L1A
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.GPR.16.16L1B
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.GPR.16.32L1C
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.GPR.16.64L1D
	nop
	b,a	vararg_error
width.GPR.32L8:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.GPR.32.8L1E
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.GPR.32.16L1F
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.GPR.32.32L20
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.GPR.32.64L21
	nop
	b,a	vararg_error
width.FPR.32LC:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.FPR.32.8L22
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.FPR.32.16L23
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.FPR.32.32L24
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.FPR.32.64L25
	nop
	b,a	vararg_error
width.FPR.64LD:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.FPR.64.8L26
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.FPR.64.16L27
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.FPR.64.32L28
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.FPR.64.64L29
	nop
	b,a	vararg_error
width.STK.8LE:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.STK.8.8L2A
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.STK.8.16L2B
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.STK.8.32L2C
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.STK.8.64L2D
	nop
	b,a	vararg_error
width.STK.16LF:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.STK.16.8L2E
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.STK.16.16L2F
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.STK.16.32L30
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.STK.16.64L31
	nop
	b,a	vararg_error
width.STK.32L10:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.STK.32.8L32
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.STK.32.16L33
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.STK.32.32L34
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.STK.32.64L35
	nop
	b,a	vararg_error
width.FSTK.32L14:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.FSTK.32.8L36
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.FSTK.32.16L37
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.FSTK.32.32L38
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.FSTK.32.64L39
	nop
	b,a	vararg_error
width.FSTK.64L15:
	ld	[%o1+8], %o3
	cmp	%o3, 8
	be,a	narrowing.FSTK.64.8L3A
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 16
	be,a	narrowing.FSTK.64.16L3B
	nop
	ld	[%o1+8], %o3
	cmp	%o3, 32
	be,a	narrowing.FSTK.64.32L3C
	nop
	ld	[%o1+8], %o4
	cmp	%o4, 64
	be,a	narrowing.FSTK.64.64L3D
	nop
	b,a	vararg_error
narrowing.GPR.8.8L16:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.8.8.stkL3E
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.8.8.r1L3F
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.8.8.r2L40
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.8.8.r3L41
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.8.8.r4L42
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.8.8.r5L43
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.8.8.r6L44
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.8.8.r7L45
	nop
	b,a	vararg_error
narrowing.GPR.8.16L17:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.8.16.stkL46
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.8.16.r1L47
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.8.16.r2L48
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.8.16.r3L49
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.8.16.r4L4A
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.8.16.r5L4B
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.8.16.r6L4C
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.8.16.r7L4D
	nop
	b,a	vararg_error
narrowing.GPR.8.32L18:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.8.32.stkL4E
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.8.32.r1L4F
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.8.32.r2L50
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.8.32.r3L51
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.8.32.r4L52
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.8.32.r5L53
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.8.32.r6L54
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.8.32.r7L55
	nop
	b,a	vararg_error
narrowing.GPR.16.8L1A:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.16.8.stkL56
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.16.8.r1L57
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.16.8.r2L58
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.16.8.r3L59
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.16.8.r4L5A
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.16.8.r5L5B
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.16.8.r6L5C
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.16.8.r7L5D
	nop
	b,a	vararg_error
narrowing.GPR.16.16L1B:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.16.16.stkL5E
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.16.16.r1L5F
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.16.16.r2L60
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.16.16.r3L61
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.16.16.r4L62
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.16.16.r5L63
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.16.16.r6L64
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.16.16.r7L65
	nop
	b,a	vararg_error
narrowing.GPR.16.32L1C:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.16.32.stkL66
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.16.32.r1L67
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.16.32.r2L68
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.16.32.r3L69
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.16.32.r4L6A
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.16.32.r5L6B
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.16.32.r6L6C
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.16.32.r7L6D
	nop
	b,a	vararg_error
narrowing.GPR.32.8L1E:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.32.8.stkL6E
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.32.8.r1L6F
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.32.8.r2L70
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.32.8.r3L71
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.32.8.r4L72
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.32.8.r5L73
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.32.8.r6L74
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.32.8.r7L75
	nop
	b,a	vararg_error
narrowing.GPR.32.16L1F:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.32.16.stkL76
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.32.16.r1L77
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.32.16.r2L78
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.32.16.r3L79
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.32.16.r4L7A
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.32.16.r5L7B
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.32.16.r6L7C
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.32.16.r7L7D
	nop
	b,a	vararg_error
narrowing.GPR.32.32L20:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.GPR.32.32.stkL7E
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.GPR.32.32.r1L7F
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.GPR.32.32.r2L80
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.GPR.32.32.r3L81
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.GPR.32.32.r4L82
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.GPR.32.32.r5L83
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.GPR.32.32.r6L84
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.GPR.32.32.r7L85
	nop
	b,a	vararg_error
narrowing.FPR.32.32L24:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.FPR.32.32.stkL86
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.FPR.32.32.r1L87
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.FPR.32.32.r2L88
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.FPR.32.32.r3L89
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.FPR.32.32.r4L8A
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.FPR.32.32.r5L8B
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.FPR.32.32.r6L8C
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.FPR.32.32.r7L8D
	nop
	b,a	vararg_error
narrowing.FPR.32.64L25:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.FPR.32.64.stkL8E
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.FPR.32.64.r1L8F
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.FPR.32.64.r2L90
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.FPR.32.64.r3L91
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.FPR.32.64.r4L92
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.FPR.32.64.r5L93
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.FPR.32.64.r6L94
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.FPR.32.64.r7L95
	nop
	b,a	vararg_error
narrowing.FPR.64.32L28:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.FPR.64.32.stkL96
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.FPR.64.32.r1L97
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.FPR.64.32.r2L98
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.FPR.64.32.r3L99
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.FPR.64.32.r4L9A
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.FPR.64.32.r5L9B
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.FPR.64.32.r6L9C
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.FPR.64.32.r7L9D
	nop
	b,a	vararg_error
narrowing.FPR.64.64L29:
	ld	[%o1+12], %o3
	cmp	%o3, %g0
	be,a	loc.FPR.64.64.stkL9E
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 1
	be,a	loc.FPR.64.64.r1L9F
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 2
	be,a	loc.FPR.64.64.r2LA0
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 3
	be,a	loc.FPR.64.64.r3LA1
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 4
	be,a	loc.FPR.64.64.r4LA2
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 5
	be,a	loc.FPR.64.64.r5LA3
	nop
	ld	[%o1+12], %o3
	cmp	%o3, 6
	be,a	loc.FPR.64.64.r6LA4
	nop
	ld	[%o1+12], %o4
	cmp	%o4, 7
	be,a	loc.FPR.64.64.r7LA5
	nop
	b,a	vararg_error
narrowing.STK.8.8L2A:
	b,a	loc.STK.8.8.stkLA6
	b,a	loc.STK.8.8.r1LA7
	b,a	loc.STK.8.8.r2LA8
	b,a	loc.STK.8.8.r3LA9
	b,a	loc.STK.8.8.r4LAA
	b,a	loc.STK.8.8.r5LAB
	b,a	loc.STK.8.8.r6LAC
	b,a	loc.STK.8.8.r7LAD
	b,a	vararg_error
narrowing.STK.8.16L2B:
	b,a	loc.STK.8.16.stkLAE
	b,a	loc.STK.8.16.r1LAF
	b,a	loc.STK.8.16.r2LB0
	b,a	loc.STK.8.16.r3LB1
	b,a	loc.STK.8.16.r4LB2
	b,a	loc.STK.8.16.r5LB3
	b,a	loc.STK.8.16.r6LB4
	b,a	loc.STK.8.16.r7LB5
	b,a	vararg_error
narrowing.STK.8.32L2C:
	b,a	loc.STK.8.32.stkLB6
	b,a	loc.STK.8.32.r1LB7
	b,a	loc.STK.8.32.r2LB8
	b,a	loc.STK.8.32.r3LB9
	b,a	loc.STK.8.32.r4LBA
	b,a	loc.STK.8.32.r5LBB
	b,a	loc.STK.8.32.r6LBC
	b,a	loc.STK.8.32.r7LBD
	b,a	vararg_error
narrowing.STK.16.8L2E:
	b,a	loc.STK.16.8.stkLBE
	b,a	loc.STK.16.8.r1LBF
	b,a	loc.STK.16.8.r2LC0
	b,a	loc.STK.16.8.r3LC1
	b,a	loc.STK.16.8.r4LC2
	b,a	loc.STK.16.8.r5LC3
	b,a	loc.STK.16.8.r6LC4
	b,a	loc.STK.16.8.r7LC5
	b,a	vararg_error
narrowing.STK.16.16L2F:
	b,a	loc.STK.16.16.stkLC6
	b,a	loc.STK.16.16.r1LC7
	b,a	loc.STK.16.16.r2LC8
	b,a	loc.STK.16.16.r3LC9
	b,a	loc.STK.16.16.r4LCA
	b,a	loc.STK.16.16.r5LCB
	b,a	loc.STK.16.16.r6LCC
	b,a	loc.STK.16.16.r7LCD
	b,a	vararg_error
narrowing.STK.16.32L30:
	b,a	loc.STK.16.32.stkLCE
	b,a	loc.STK.16.32.r1LCF
	b,a	loc.STK.16.32.r2LD0
	b,a	loc.STK.16.32.r3LD1
	b,a	loc.STK.16.32.r4LD2
	b,a	loc.STK.16.32.r5LD3
	b,a	loc.STK.16.32.r6LD4
	b,a	loc.STK.16.32.r7LD5
	b,a	vararg_error
narrowing.STK.32.8L32:
	b,a	loc.STK.32.8.stkLD6
	b,a	loc.STK.32.8.r1LD7
	b,a	loc.STK.32.8.r2LD8
	b,a	loc.STK.32.8.r3LD9
	b,a	loc.STK.32.8.r4LDA
	b,a	loc.STK.32.8.r5LDB
	b,a	loc.STK.32.8.r6LDC
	b,a	loc.STK.32.8.r7LDD
	b,a	vararg_error
narrowing.STK.32.16L33:
	b,a	loc.STK.32.16.stkLDE
	b,a	loc.STK.32.16.r1LDF
	b,a	loc.STK.32.16.r2LE0
	b,a	loc.STK.32.16.r3LE1
	b,a	loc.STK.32.16.r4LE2
	b,a	loc.STK.32.16.r5LE3
	b,a	loc.STK.32.16.r6LE4
	b,a	loc.STK.32.16.r7LE5
	b,a	vararg_error
narrowing.STK.32.32L34:
	b,a	loc.STK.32.32.stkLE6
	b,a	loc.STK.32.32.r1LE7
	b,a	loc.STK.32.32.r2LE8
	b,a	loc.STK.32.32.r3LE9
	b,a	loc.STK.32.32.r4LEA
	b,a	loc.STK.32.32.r5LEB
	b,a	loc.STK.32.32.r6LEC
	b,a	loc.STK.32.32.r7LED
	b,a	vararg_error
narrowing.FSTK.32.32L38:
	b,a	loc.FSTK.32.32.stkLEE
	b,a	loc.FSTK.32.32.r1LEF
	b,a	loc.FSTK.32.32.r2LF0
	b,a	loc.FSTK.32.32.r3LF1
	b,a	loc.FSTK.32.32.r4LF2
	b,a	loc.FSTK.32.32.r5LF3
	b,a	loc.FSTK.32.32.r6LF4
	b,a	loc.FSTK.32.32.r7LF5
	b,a	vararg_error
narrowing.FSTK.32.64L39:
	b,a	loc.FSTK.32.64.stkLF6
	b,a	loc.FSTK.32.64.r1LF7
	b,a	loc.FSTK.32.64.r2LF8
	b,a	loc.FSTK.32.64.r3LF9
	b,a	loc.FSTK.32.64.r4LFA
	b,a	loc.FSTK.32.64.r5LFB
	b,a	loc.FSTK.32.64.r6LFC
	b,a	loc.FSTK.32.64.r7LFD
	b,a	vararg_error
narrowing.FSTK.64.32L3C:
	b,a	loc.FSTK.64.32.stkLFE
	b,a	loc.FSTK.64.32.r1LFF
	b,a	loc.FSTK.64.32.r2L100
	b,a	loc.FSTK.64.32.r3L101
	b,a	loc.FSTK.64.32.r4L102
	b,a	loc.FSTK.64.32.r5L103
	b,a	loc.FSTK.64.32.r6L104
	b,a	loc.FSTK.64.32.r7L105
	b,a	vararg_error
narrowing.FSTK.64.64L3D:
	b,a	loc.FSTK.64.64.stkL106
	b,a	loc.FSTK.64.64.r1L107
	b,a	loc.FSTK.64.64.r2L108
	b,a	loc.FSTK.64.64.r3L109
	b,a	loc.FSTK.64.64.r4L10A
	b,a	loc.FSTK.64.64.r5L10B
	b,a	loc.FSTK.64.64.r6L10C
	b,a	loc.FSTK.64.64.r7L10D
	b,a	vararg_error
loc.GPR.8.8.stkL3E:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.8.r1L3F:
	ld	[%fp+160], %g1
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldub	[%o3+%o4], %o4
	st	%o4, [%fp+160]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.8.r2L40:
	ld	[%fp+168], %g2
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldub	[%o3+%o4], %o4
	st	%o4, [%fp+168]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.8.r3L41:
	ld	[%fp+176], %g3
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldub	[%o3+%o4], %o4
	st	%o4, [%fp+176]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.8.r4L42:
	ld	[%fp+0], %g4
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldub	[%o3+%o4], %o4
	st	%o4, [%fp+0]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.8.r5L43:
	ld	[%fp+4], %g5
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldub	[%o3+%o4], %o3
	st	%o3, [%fp+4]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.8.r6L44:
	ld	[%fp+16], %g6
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldub	[%o3+%o4], %o4
	st	%o4, [%fp+16]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.8.r7L45:
	ld	[%fp+24], %g7
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldub	[%o3+%o4], %o4
	st	%o4, [%fp+24]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.16.stkL46:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.16.r1L47:
	ld	[%fp+36], %g1
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o3
	st	%o3, [%fp+36]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.16.r2L48:
	ld	[%fp+44], %g2
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o3
	st	%o3, [%fp+44]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.16.r3L49:
	ld	[%fp+52], %g3
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o3
	st	%o3, [%fp+52]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.16.r4L4A:
	ld	[%fp+56], %g4
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o4
	st	%o4, [%fp+56]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.16.r5L4B:
	ld	[%fp+60], %g5
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o3
	st	%o3, [%fp+60]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.16.r6L4C:
	ld	[%fp+64], %g6
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o4
	st	%o4, [%fp+64]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.16.r7L4D:
	ld	[%fp+68], %g7
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o3
	st	%o3, [%fp+68]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.32.stkL4E:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.32.r1L4F:
	ld	[%fp+80], %g1
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o4
	st	%o4, [%fp+80]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.32.r2L50:
	ld	[%fp+84], %g2
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o3
	st	%o3, [%fp+84]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.32.r3L51:
	ld	[%fp+92], %g3
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o3
	st	%o3, [%fp+92]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.32.r4L52:
	ld	[%fp+100], %g4
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o3
	st	%o3, [%fp+100]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.32.r5L53:
	ld	[%fp+104], %g5
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o4
	st	%o4, [%fp+104]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.32.r6L54:
	ld	[%fp+112], %g6
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o4
	st	%o4, [%fp+112]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.8.32.r7L55:
	ld	[%fp+120], %g7
	add	%o1, 20, %o3
	ldub	[%o1+16], %o4
	ldsb	[%o3+%o4], %o4
	st	%o4, [%fp+120]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.8.stkL56:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.8.r1L57:
	ld	[%fp+136], %g1
	add	%o1, 20, %o3
	lduh	[%o1+16], %o4
	ldsh	[%o3+%o4], %o4
	st	%o4, [%fp+136]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.8.r2L58:
	mov	%o5, %g2
	add	%o1, 20, %o5
	lduh	[%o1+16], %o3
	ldsh	[%o5+%o3], %o5
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.8.r3L59:
	mov	%o7, %g3
	add	%o1, 20, %o4
	lduh	[%o1+16], %o7
	ldsh	[%o4+%o7], %o7
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.8.r4L5A:
	mov	%l0, %g4
	add	%o1, 20, %l0
	lduh	[%o1+16], %o3
	ldsh	[%l0+%o3], %l0
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.8.r5L5B:
	mov	%l1, %g5
	add	%o1, 20, %o4
	lduh	[%o1+16], %l1
	ldsh	[%o4+%l1], %l1
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.8.r6L5C:
	mov	%l2, %g6
	add	%o1, 20, %l2
	lduh	[%o1+16], %o3
	ldsh	[%l2+%o3], %l2
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.8.r7L5D:
	mov	%l3, %g7
	add	%o1, 20, %o4
	lduh	[%o1+16], %l3
	ldsh	[%o4+%l3], %l3
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.16.stkL5E:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.16.r1L5F:
	mov	%l4, %g1
	add	%o1, 20, %l4
	lduh	[%o1+16], %o3
	lduh	[%l4+%o3], %l4
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.16.r2L60:
	mov	%l5, %g2
	add	%o1, 20, %o4
	lduh	[%o1+16], %l5
	lduh	[%o4+%l5], %l5
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.16.r3L61:
	mov	%l6, %g3
	add	%o1, 20, %l6
	lduh	[%o1+16], %o3
	lduh	[%l6+%o3], %l6
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.16.r4L62:
	mov	%l7, %g4
	add	%o1, 20, %o4
	lduh	[%o1+16], %l7
	lduh	[%o4+%l7], %l7
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.16.r5L63:
	mov	%i0, %g5
	add	%o1, 20, %i0
	lduh	[%o1+16], %o3
	lduh	[%i0+%o3], %i0
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.16.r6L64:
	mov	%i1, %g6
	add	%o1, 20, %o4
	lduh	[%o1+16], %i1
	lduh	[%o4+%i1], %i1
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.16.r7L65:
	mov	%i2, %g7
	add	%o1, 20, %i2
	lduh	[%o1+16], %o3
	lduh	[%i2+%o3], %i2
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.32.stkL66:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.32.r1L67:
	mov	%i3, %g1
	add	%o1, 20, %o4
	lduh	[%o1+16], %i3
	ldsh	[%o4+%i3], %i3
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.32.r2L68:
	mov	%i4, %g2
	add	%o1, 20, %i4
	lduh	[%o1+16], %o3
	ldsh	[%i4+%o3], %i4
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.32.r3L69:
	mov	%i5, %g3
	add	%o1, 20, %o4
	lduh	[%o1+16], %i5
	ldsh	[%o4+%i5], %i5
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.32.r4L6A:
	mov	%i7, %g4
	add	%o1, 20, %i7
	lduh	[%o1+16], %o3
	ldsh	[%i7+%o3], %i7
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.32.r5L6B:
	ld	[%fp+180], %g5
	add	%o1, 20, %o4
	lduh	[%o1+16], %o3
	ldsh	[%o4+%o3], %o3
	st	%o3, [%fp+180]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.32.r6L6C:
	ld	[%fp+72], %g6
	add	%o1, 20, %o4
	lduh	[%o1+16], %o3
	ldsh	[%o4+%o3], %o4
	st	%o4, [%fp+72]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.16.32.r7L6D:
	ld	[%fp+76], %g7
	add	%o1, 20, %o4
	lduh	[%o1+16], %o3
	ldsh	[%o4+%o3], %o3
	st	%o3, [%fp+76]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.8.stkL6E:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.8.r1L6F:
	ld	[%fp+88], %g1
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+88]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.8.r2L70:
	ld	[%fp+96], %g2
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+96]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.8.r3L71:
	ld	[%fp+108], %g3
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+108]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.8.r4L72:
	ld	[%fp+116], %g4
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+116]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.8.r5L73:
	ld	[%fp+124], %g5
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+124]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.8.r6L74:
	ld	[%fp+128], %g6
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+128]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.8.r7L75:
	ld	[%fp+132], %g7
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+132]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.16.stkL76:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.16.r1L77:
	ld	[%fp+140], %g1
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+140]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.16.r2L78:
	ld	[%fp+144], %g2
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+144]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.16.r3L79:
	ld	[%fp+148], %g3
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+148]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.16.r4L7A:
	ld	[%fp+152], %g4
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+152]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.16.r5L7B:
	ld	[%fp+156], %g5
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+156]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.16.r6L7C:
	ld	[%fp+164], %g6
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+164]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.16.r7L7D:
	ld	[%fp+172], %g7
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+172]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.32.stkL7E:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.32.r1L7F:
	ld	[%fp+8], %g1
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+8]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.32.r2L80:
	ld	[%fp+12], %g2
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+12]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.32.r3L81:
	ld	[%fp+20], %g3
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+20]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.32.r4L82:
	ld	[%fp+28], %g4
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o3
	st	%o3, [%fp+28]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.32.r5L83:
	ld	[%fp+32], %g5
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+32]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.32.r6L84:
	ld	[%fp+40], %g6
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+40]
	b,a	interpL1E3
	b,a	vararg_error
loc.GPR.32.32.r7L85:
	ld	[%fp+48], %g7
	add	%o1, 20, %o4
	ld	[%o1+16], %o3
	ld	[%o4+%o3], %o4
	st	%o4, [%fp+48]
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.32.stkL86:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.32.r1L87:
	lddf	[%fp+240], %g1
	ldf	[%o1+20], %f30
	stdf	[%fp+240], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.32.r2L88:
	lddf	[%fp+248], %g2
	ldf	[%o1+20], %f30
	stdf	[%fp+248], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.32.r3L89:
	lddf	[%fp+256], %g3
	ldf	[%o1+20], %f30
	stdf	[%fp+256], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.32.r4L8A:
	lddf	[%fp+264], %g4
	ldf	[%o1+20], %f30
	stdf	[%fp+264], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.32.r5L8B:
	lddf	[%fp+272], %g5
	ldf	[%o1+20], %f30
	stdf	[%fp+272], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.32.r6L8C:
	lddf	[%fp+280], %g6
	ldf	[%o1+20], %f30
	stdf	[%fp+280], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.32.r7L8D:
	fmovs	%f26, %f7
	fmovs	%f27, %f8
	ldf	[%o1+20], %f26
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.64.stkL8E:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.64.r1L8F:
	fmovs	%f22, %f1
	fmovs	%f23, %f2
	ldf	[%o1+20], %f22
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.64.r2L90:
	fmovs	%f18, %f2
	fmovs	%f19, %f3
	ldf	[%o1+20], %f18
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.64.r3L91:
	fmovs	%f16, %f3
	fmovs	%f17, %f4
	ldf	[%o1+20], %f16
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.64.r4L92:
	fmovs	%f14, %f4
	fmovs	%f15, %f5
	ldf	[%o1+20], %f14
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.64.r5L93:
	fmovs	%f12, %f5
	fmovs	%f13, %f6
	ldf	[%o1+20], %f12
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.64.r6L94:
	fmovs	%f10, %f6
	fmovs	%f11, %f7
	ldf	[%o1+20], %f10
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.32.64.r7L95:
	fmovs	%f8, %f7
	fmovs	%f9, %f8
	ldf	[%o1+20], %f8
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.32.stkL96:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.32.r1L97:
	fmovs	%f6, %f1
	fmovs	%f7, %f2
	lddf	[%o1+20], %f6
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.32.r2L98:
	fmovs	%f4, %f2
	fmovs	%f5, %f3
	lddf	[%o1+20], %f4
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.32.r3L99:
	fmovs	%f2, %f3
	fmovs	%f3, %f4
	lddf	[%o1+20], %f2
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.32.r4L9A:
	fmovs	%f0, %f4
	fmovs	%f1, %f5
	lddf	[%o1+20], %f0
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.32.r5L9B:
	fmovs	%f20, %f5
	fmovs	%f21, %f6
	lddf	[%o1+20], %f20
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.32.r6L9C:
	fmovs	%f24, %f6
	fmovs	%f25, %f7
	lddf	[%o1+20], %f24
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.32.r7L9D:
	fmovs	%f28, %f7
	fmovs	%f29, %f8
	lddf	[%o1+20], %f28
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.64.stkL9E:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.64.r1L9F:
	lddf	[%fp+184], %g1
	lddf	[%o1+20], %f30
	stdf	[%fp+184], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.64.r2LA0:
	lddf	[%fp+192], %g2
	lddf	[%o1+20], %f30
	stdf	[%fp+192], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.64.r3LA1:
	lddf	[%fp+200], %g3
	lddf	[%o1+20], %f30
	stdf	[%fp+200], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.64.r4LA2:
	lddf	[%fp+208], %g4
	lddf	[%o1+20], %f30
	stdf	[%fp+208], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.64.r5LA3:
	lddf	[%fp+216], %g5
	lddf	[%o1+20], %f30
	stdf	[%fp+216], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.64.r6LA4:
	lddf	[%fp+224], %g6
	lddf	[%o1+20], %f30
	stdf	[%fp+224], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FPR.64.64.r7LA5:
	lddf	[%fp+232], %g7
	lddf	[%o1+20], %f30
	stdf	[%fp+232], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.8.stkLA6:
	ld	[%o1+12], %o4
	ldub	[%o1+20], %o3
	stb	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.8.r1LA7:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.8.r2LA8:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.8.r3LA9:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.8.r4LAA:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.8.r5LAB:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.8.r6LAC:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.8.r7LAD:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.16.stkLAE:
	ld	[%o1+12], %o4
	ldub	[%o1+20], %o3
	stb	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.16.r1LAF:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.16.r2LB0:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.16.r3LB1:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.16.r4LB2:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.16.r5LB3:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.16.r6LB4:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.16.r7LB5:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.32.stkLB6:
	ld	[%o1+12], %o4
	ldub	[%o1+20], %o3
	stb	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.32.r1LB7:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.32.r2LB8:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.32.r3LB9:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.32.r4LBA:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.32.r5LBB:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.32.r6LBC:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.8.32.r7LBD:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.8.stkLBE:
	ld	[%o1+12], %o4
	lduh	[%o1+20], %o3
	sth	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.8.r1LBF:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.8.r2LC0:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.8.r3LC1:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.8.r4LC2:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.8.r5LC3:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.8.r6LC4:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.8.r7LC5:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.16.stkLC6:
	ld	[%o1+12], %o4
	lduh	[%o1+20], %o3
	sth	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.16.r1LC7:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.16.r2LC8:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.16.r3LC9:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.16.r4LCA:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.16.r5LCB:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.16.r6LCC:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.16.r7LCD:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.32.stkLCE:
	ld	[%o1+12], %o4
	lduh	[%o1+20], %o3
	sth	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.32.r1LCF:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.32.r2LD0:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.32.r3LD1:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.32.r4LD2:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.32.r5LD3:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.32.r6LD4:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.16.32.r7LD5:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.8.stkLD6:
	ld	[%o1+12], %o4
	ld	[%o1+20], %o3
	st	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.8.r1LD7:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.8.r2LD8:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.8.r3LD9:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.8.r4LDA:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.8.r5LDB:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.8.r6LDC:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.8.r7LDD:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.16.stkLDE:
	ld	[%o1+12], %o4
	ld	[%o1+20], %o3
	st	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.16.r1LDF:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.16.r2LE0:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.16.r3LE1:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.16.r4LE2:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.16.r5LE3:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.16.r6LE4:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.16.r7LE5:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.32.stkLE6:
	ld	[%o1+12], %o4
	ld	[%o1+20], %o3
	st	%o3, [%sp+%o4]
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.32.r1LE7:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.32.r2LE8:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.32.r3LE9:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.32.r4LEA:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.32.r5LEB:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.32.r6LEC:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.STK.32.32.r7LED:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.32.stkLEE:
	ld	[%o1+12], %o4
	ldf	[%o1+20], %f30
	stf	[%sp+%o4], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.32.r1LEF:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.32.r2LF0:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.32.r3LF1:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.32.r4LF2:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.32.r5LF3:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.32.r6LF4:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.32.r7LF5:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.64.stkLF6:
	ld	[%o1+12], %o3
	ldf	[%o1+20], %f30
	stf	[%sp+%o3], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.64.r1LF7:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.64.r2LF8:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.64.r3LF9:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.64.r4LFA:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.64.r5LFB:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.64.r6LFC:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.32.64.r7LFD:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.32.stkLFE:
	ld	[%o1+12], %o4
	lddf	[%o1+20], %f30
	stdf	[%sp+%o4], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.32.r1LFF:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.32.r2L100:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.32.r3L101:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.32.r4L102:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.32.r5L103:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.32.r6L104:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.32.r7L105:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.64.stkL106:
	ld	[%o1+12], %o3
	lddf	[%o1+20], %f30
	stdf	[%sp+%o3], %f30
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.64.r1L107:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.64.r2L108:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.64.r3L109:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.64.r4L10A:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.64.r5L10B:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.64.r6L10C:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
loc.FSTK.64.64.r7L10D:
	b,a	vararg_error
	b,a	interpL1E3
	b,a	vararg_error
gotoCL1E4:
	/* Liveout:  GP={%o0}  */
	jmpl	%o0+%g0, %o7
	nop
	retl
	nop
	.global	VarargInterp
